
/**
 * Active object to create a series of flying fruits for 
 * Fruit Ninja game
 * 
 * @author Jim Teresco
 */
import objectdraw.*;
import java.awt.*;
import java.util.Random;

public class FruitLauncher extends ActiveObject {

    // we'll create between 3 and 7 FlyingFruits per FruitLauncher
    private static final int MIN_FRUITS = 3;
    private static final int MAX_FRUITS = 7;
    // in ms:
    private static final int AVERAGE_INTERVAL = 500;
    
    // just some information we need to remember from the parameters
    // to the constructor that need to be used in the run method, where
    // they are passed to the FlyingFruit constructor
    private DrawingCanvas c;
    private FruitNinja game;
    
    // constructor remembers a few bits of information then activates
    public FruitLauncher(FruitNinja game, DrawingCanvas c) {
        
        this.c = c;
        this.game = game;
        
        start();
    }
    
    // the life our our launcher is to decide how many to launch, then launch them
    public void run() {
        Random r = new Random();
        int numFruits = r.nextInt(MAX_FRUITS - MIN_FRUITS) + MIN_FRUITS;
        
        for (int fruitNum = 0; fruitNum < numFruits; fruitNum++) {
            new FlyingFruit(game, c);
            pause(AVERAGE_INTERVAL);
        }
    }
}
