import objectdraw.*;
import java.awt.*;
import java.util.ArrayList;
import java.util.Random;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;

/*
 * Example FruitNinja: an example final project that implements a simplified version
 * of the "Fruit Ninja" game.  Each time the user presses the button to launch
 * more flying fruit, an active object is created that in turn creates a series of
 * flying fruit.  The player attempts to drag the mouse over each flying fruit object
 * to earn a point.  If they do not do so before it falls off the bottom of the canvas,
 * a miss is recorded.  When 3 misses are recorded, the game ends.
 *
 * Jim Teresco, The College of Saint Rose, CSC 252, Spring 2016
 *
 * $Id: FruitNinja.java 2915 2016-03-24 02:23:40Z terescoj $
 */

public class FruitNinja extends WindowController implements ActionListener {

    // how many fruits can you miss before the game ends?
    private static final int MAX_MISSES = 3;
    
    // instance variables to keep track of scoring
    private JLabel scoreLabel;
    private int score, misses;
    
    // the game keeps a list of FlyingFruit objects currently in the air
    private ArrayList<FlyingFruit> fruitList;

    public void begin() {
        setSize(600, 600);

        Container contentPane = getContentPane();

        // A JPanel, in which we will group together our JButton
        // and JLabel for the score
        JPanel southPanel = new JPanel();

        JButton nextButton = new JButton("Next Round");
        southPanel.add(nextButton);

        scoreLabel = new JLabel("Score: 0, Misses: 0");
        southPanel.add(scoreLabel);

        // listen for button presses
        nextButton.addActionListener(this);

        // get our panel into the pane
        contentPane.add(southPanel, BorderLayout.SOUTH);

        contentPane.validate();

        // arraylist of FlyingFruit objects
        fruitList = new ArrayList<FlyingFruit>();
    }

    // handle button press, only one button so it's simple
    public void actionPerformed(ActionEvent e) {

        if (misses < MAX_MISSES) {
            // the FruitLauncher is responsible for launching a series of
            // FlyingFruit objects
            new FruitLauncher(this, canvas);
        }
    }

    // method to inform the game that there's a new FlyingFruit
    // in the air to check in our drag
    public synchronized void newFruit(FlyingFruit f) {

        fruitList.add(f);
    }

    // method to inform the game that a piece of fruit is done, either
    // because the fruit was hit or it went off the canvas, as indicated 
    // by the second parameter
    public synchronized void fruitDone(FlyingFruit f, boolean hit) {

        if (!hit) {
            if (misses < MAX_MISSES) {
                misses++;
                scoreLabel.setText("Score: " + score + ", Misses: " + misses);            
            }
            if (misses == MAX_MISSES) {
                new FilledRect(0, 0, canvas.getWidth(), canvas.getHeight(), canvas).setColor(Color.red);
                Text gameOver = new Text("Game Over!", 0, 0, canvas);
                gameOver.setColor(Color.white);
                gameOver.setFontSize(20);
                gameOver.move(canvas.getWidth()/2 - gameOver.getWidth()/2,
                    canvas.getHeight()/2 - gameOver.getHeight()/2);
            }                
        }
        fruitList.remove(f);
    }

    // the only mouse event we care about is onMouseDrag, we simply loop over
    // all of the FlyingFruit objects currently in play and see if any of them
    // contain the point
    public void onMouseDrag(Location point) {

        if (misses < MAX_MISSES) {
            for (FlyingFruit f : fruitList) {

                if (f.contains(point)) {
                    f.hit();
                    score++;
                }
            }
            scoreLabel.setText("Score: " + score + ", Misses: " + misses);
        }
    }
}
