
/**
 * Shrapnel of a hit fruit object, just a straightforward
 * animation of an object subject to acceleration due to
 * gravity with no other real interactions.
 * 
 * @author Jim Teresco
 */
import objectdraw.*;
import java.awt.*;
import java.util.Random;

public class Shrapnel extends ActiveObject {
    
    // animation parameters
    private static final double MAX_SPEED_CHANGE = 2;
    private static final double SHRAPNEL_SIZE = 20;
    private static final int PAUSE_TIME = 33;
    private static final double GRAVITY = 0.1;
    
    // instance variables for the actual graphical object, and its
    // animation speeds
    private FilledOval s;
    private double xSpeed, ySpeed;
    
    // we'll need this (or just its height) to decide when we've gone
    // off the bottom - using the canvas itself means things are still ok
    // if the canvas gets resized.
    private DrawingCanvas c;
    private static Random r = new Random();
    
    // construct our shrapnel
    public Shrapnel(double x, double y, double xSpeed, double ySpeed, 
                    Color color, DrawingCanvas c) {

        this.c = c;
        
        s = new FilledOval(x - SHRAPNEL_SIZE/2, y - SHRAPNEL_SIZE/2, SHRAPNEL_SIZE,
                           SHRAPNEL_SIZE, c);
        s.setColor(color);
        
        // choose a random speed similar to current speed
        this.xSpeed = xSpeed + r.nextDouble()*2*MAX_SPEED_CHANGE - MAX_SPEED_CHANGE;
        this.ySpeed = ySpeed + r.nextDouble()*2*MAX_SPEED_CHANGE - MAX_SPEED_CHANGE;
        
        start();
    }

    // the simple life of fruit shrapnel
    public void run() {
        
        while (s.getY() < c.getHeight()) {
           
            s.move(xSpeed, ySpeed);
            pause(PAUSE_TIME);
            ySpeed += GRAVITY;
        }
        s.removeFromCanvas();
        
    }
}
